AVATAR_URL: dict[str, str] = {
    "Qiqi": "https://i0.hdslb.com/bfs/album/9450494338e94d665b43a05ebfb120fbcc9485ab.jpg",
}


FONT_AWESOME_URL: str = "https://github.com/FortAwesome/Font-Awesome/raw/6.x/svgs/"
